@@ -1,18 +1,43 @@
 # -*- coding: utf-8 -*-
 # -*- Mode: Python; py-indent-offset: 4 -*-
+
+import gi
+gi.require_version('Notify', '0.7')
+gi.require_version('Gtk', '3.0')
+gi.require_version('Notify', '0.7')
+gi.require_version('Gst', '1.0')
+from gi.repository import Gtk, Gdk, Notify, Gst, GObject
+
 import os, os.path
-import itl
-from monajat import Monajat
-from utils import init_dbus
+from monajat import itl
+from monajat.monajat import Monajat
+from monajat.utils import setup_dbus
 import locale, gettext
 import re
 
-from gi.repository import Gtk, Gdk, Notify, Gst, GObject
-import cgi
+import html
 import math
 import json
 import time
 
+from threading import Timer, Thread, Event
+
+def MainTimer(sec):
+    def decorator(function):
+        def wrapper(*args, **kwargs):
+            stopped = Event()
+
+            def loop(): 
+                while not stopped.wait(sec): 
+                    function(*args, **kwargs)
+
+            t = Thread(target=loop)
+            t.daemon = True
+            t.start()
+            return stopped
+        return wrapper
+    return decorator
+
 # in gnome3 ['actions', 'action-icons', 'body', 'body-markup', 'icon-static', 'persistence']
 # in gnome2 ['actions', 'body', 'body-hyperlinks', 'body-markup', 'icon-static', 'sound']
 # "resident"
@@ -47,7 +72,7 @@ class SoundPlayer(object):
         
     def on_message(self, bus, message):
         if message:
-            print message
+            print (message)
         self.gst_player.set_state(Gst.State.NULL)
 
 normalize_tb = {
@@ -61,7 +86,7 @@ def to_uincode(Str):
         Str = str(Str)
     except UnicodeEncodeError:
         pass
-    if type(Str) == unicode:
+    if type(Str) == str:
         return Str.translate(normalize_tb)
     else:
         return Str.decode('utf-8').translate(normalize_tb)
@@ -76,23 +101,41 @@ class ConfigDlg(Gtk.Dialog):
         self.set_resizable(False) # FIXME: reconsider this
         self.connect('delete-event', lambda w,*a: w.hide() or True)
         self.connect('response', lambda w,*a: w.hide() or True)
-        self.set_title(_('Monajat Configuration'))
-        self.add_button(_('Cancel'), Gtk.ResponseType.CANCEL)
-        self.add_button(_('Save'), Gtk.ResponseType.OK)
+        self.set_title(('Monajat Configuration'))
+        self.add_button(('Cancel'), Gtk.ResponseType.CANCEL)
+        self.add_button(('Save'), Gtk.ResponseType.OK)
         tabs = Gtk.Notebook()
         tabs.set_size_request(-1,350)
         self.get_content_area().add(tabs)
         vb = Gtk.VBox(False, 2)
-        tabs.append_page(vb, Gtk.Label(_('Generic')))
-        self.auto_start = b = Gtk.CheckButton(_("Auto start"))
+        tabs.append_page(vb, Gtk.Label(('Generic')))
+        self.auto_start = b = Gtk.CheckButton(("Auto start"))
         self.auto_start.set_active(not os.path.exists(self.applet.skip_auto_fn))
         vb.pack_start(b, False, False, 2)
-        self.show_merits = b = Gtk.CheckButton(_("Show merits"))
+        self.show_merits = b = Gtk.CheckButton(("Show merits"))
         self.show_merits.set_active(self.applet.conf['show_merits'])
         vb.pack_start(b, False, False, 2)
+        self.daylight_savings_time = b = Gtk.CheckButton(("daylight_savings_time"))
+        self.daylight_savings_time.set_active(self.applet.conf['daylight_savings_time'])
+        vb.pack_start(b, False, False, 2)        
         hb = Gtk.HBox()
         vb.pack_start(hb, False, False, 2)
-        hb.pack_start(Gtk.Label(_('Language:')), False, False, 2)
+        hb.pack_start(Gtk.Label(('method:')), False, False, 2)
+        self.pt_method = b = Gtk.ComboBoxText.new()
+        hb.pack_end(b, False, False, 2)
+        b.append_text("none. Set to default")
+        b.append_text("Egyptian General Authority of Survey")
+        b.append_text("University of Islamic Sciences, Karachi (Shaf'i)")
+        b.append_text("University of Islamic Sciences, Karachi (Hanafi)")
+        b.append_text("Islamic Society of North America")
+        b.append_text("Muslim World League (MWL)")
+        b.append_text("Umm Al-Qurra, Saudi Arabia")
+        b.append_text("Fixed Ishaa Interval (always 90)")
+        b.append_text("Egyptian General Authority of Survey (Egypt)")
+        b.set_active(self.applet.conf['pt_method'])      
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(('Language:')), False, False, 2)
         self.lang = b = Gtk.ComboBoxText.new()
         hb.pack_end(b, False, False, 2)
         selected = 0
@@ -104,20 +147,20 @@ class ConfigDlg(Gtk.Dialog):
         
         hb = Gtk.HBox()
         vb.pack_start(hb, False, False, 2)
-        hb.pack_start(Gtk.Label(_('Time:')), False, False, 2)
+        hb.pack_start(Gtk.Label(('Time:')), False, False, 2)
         hb.pack_start(Gtk.HBox(), True, True, 2)
         adj = Gtk.Adjustment(5, 0, 90, 5, 5)
         self.timeout = b = Gtk.SpinButton()
         b.set_adjustment(adj)
         b.set_value(self.applet.conf['minutes'])
         hb.pack_start(b, False, False, 2)
-        hb.pack_start(Gtk.Label(_('minutes')), False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
 
         vb = Gtk.VBox(False, 2)
-        tabs.append_page(vb, Gtk.Label(_('Location')))
+        tabs.append_page(vb, Gtk.Label(('Location')))
         
         hb = Gtk.HBox()
-        hb.pack_start(Gtk.Label(_('Current city:')), False, False, 2)
+        hb.pack_start(Gtk.Label(('Current city:')), False, False, 2)
         vb.pack_start(hb, False, False, 6)
         hb = Gtk.HBox()
         vb.pack_start(hb, False, False, 2)
@@ -128,7 +171,7 @@ class ConfigDlg(Gtk.Dialog):
             self.user_city = c['name']
         else:
             c = {}
-            c['country'] = _('Please, Secify your city')
+            c['country'] = ('Please, Secify your city')
             c['state'] = ''
             c['name'] = ''
             c['locale_name'] = ''
@@ -142,7 +185,7 @@ class ConfigDlg(Gtk.Dialog):
         hb.pack_start(l, True, True, 2)
         
         hb = Gtk.HBox()
-        hb.pack_start(Gtk.Label(_('Change city:')), False, False, 2)
+        hb.pack_start(Gtk.Label(('Change city:')), False, False, 2)
         vb.pack_start(hb, False, False, 8)
         self.Search_e = e = Gtk.Entry()
         e.connect('activate', self._city_search_cb)
@@ -164,32 +207,112 @@ class ConfigDlg(Gtk.Dialog):
         vb.pack_start(scroll, True, True, 2)
         self.sound_player = SoundPlayer(self.applet.conf['athan_media_file'],
                                         self.change_play_status)
+
         vb = Gtk.VBox(False, 2)
-        tabs.append_page(vb, Gtk.Label(_('Notification')))
+        tabs.append_page(vb, Gtk.Label(('Edit_pt')))
+        
+        self.Edit_pt = b = Gtk.CheckButton(("Edit_pt"))
+        self.Edit_pt.set_active(self.applet.conf['Edit_pt'])
+        vb.pack_start(b, False, False, 2)
+
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(('Fajr')), False, False, 2)
+        hb.pack_start(Gtk.HBox(), True, True, 2)
+        adj = Gtk.Adjustment(5, -60, 60, 1, 5)
+        self.Fajr_min = b = Gtk.SpinButton()
+        b.set_adjustment(adj)
+        b.set_value(self.applet.conf['Fajr_minutes'])
+        hb.pack_start(b, False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
+        
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(('Sunrise')), False, False, 2)
+        hb.pack_start(Gtk.HBox(), True, True, 2)
+        adj = Gtk.Adjustment(5, -60, 60, 1, 5)
+        self.Shrooq_min = b = Gtk.SpinButton()
+        b.set_adjustment(adj)
+        b.set_value(self.applet.conf['Shrooq_minutes'])
+        hb.pack_start(b, False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
+        
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(('Dhuhr')), False, False, 2)
+        hb.pack_start(Gtk.HBox(), True, True, 2)
+        adj = Gtk.Adjustment(5, -60, 60, 1, 5)
+        self.Zuhr_min = b = Gtk.SpinButton()
+        b.set_adjustment(adj)
+        b.set_value(self.applet.conf['Zuhr_minutes'])
+        hb.pack_start(b, False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
+        
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(('Asr')), False, False, 2)
+        hb.pack_start(Gtk.HBox(), True, True, 2)
+        adj = Gtk.Adjustment(5, -60, 60, 1, 5)
+        self.Asr_min = b = Gtk.SpinButton()
+        b.set_adjustment(adj)
+        b.set_value(self.applet.conf['Asr_minutes'])
+        hb.pack_start(b, False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
+        
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(('Maghrib')), False, False, 2)
+        hb.pack_start(Gtk.HBox(), True, True, 2)
+        adj = Gtk.Adjustment(5, -60, 60, 1, 5)
+        self.Maghrib_min = b = Gtk.SpinButton()
+        b.set_adjustment(adj)
+        b.set_value(self.applet.conf['Maghrib_minutes'])
+        hb.pack_start(b, False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
+        
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        hb.pack_start(Gtk.Label(("Isha'a")), False, False, 2)
+        hb.pack_start(Gtk.HBox(), True, True, 2)
+        adj = Gtk.Adjustment(5, -60, 60, 1, 5)
+        self.Ishaa_min = b = Gtk.SpinButton()
+        b.set_adjustment(adj)
+        b.set_value(self.applet.conf['Ishaa_minutes'])
+        hb.pack_start(b, False, False, 2)
+        hb.pack_start(Gtk.Label(('minutes')), False, False, 2)
+        
+        hb = Gtk.HBox()
+        vb.pack_start(hb, False, False, 2)
+        self.clear = cb = Gtk.Button(('Clear'))
+        cb.connect('clicked', self.clear_pt_changes)
+        hb.pack_end(cb, False, False, 2)
+
+        vb = Gtk.VBox(False, 2)
+        tabs.append_page(vb, Gtk.Label(('Notification')))
         hb = Gtk.HBox()
         vb.pack_start(hb, False, True, 3)
-        hb.pack_start(Gtk.Label(_('Sound:')), False, True, 2)
-        self.sound_file = b = Gtk.FileChooserButton(_('Choose Athan media file'))
+        hb.pack_start(Gtk.Label(('Sound:')), False, True, 2)
+        self.sound_file = b = Gtk.FileChooserButton(('Choose Athan media file'))
         
         if os.path.isfile(self.applet.conf['athan_media_file']):
             self.sound_file.set_filename(self.applet.conf['athan_media_file'])
         ff = Gtk.FileFilter()
-        ff.set_name(_('Sound Files'))
+        ff.set_name(('Sound Files'))
         ff.add_pattern('*.ogg')
         ff.add_pattern('*.mp3')
         b.add_filter(ff)
         ff = Gtk.FileFilter()
-        ff.set_name(_('All files'))
+        ff.set_name(('All files'))
         ff.add_pattern('*')
         b.add_filter(ff)
-        self.play_b = pb = Gtk.Button(_('Play'))
+        self.play_b = pb = Gtk.Button(('Play'))
         pb.connect('clicked', self.play_cb)
         hb.pack_end(pb, False, False, 2)
         hb.pack_end(b, True, True, 5)
         
         hb = Gtk.HBox()
         vb.pack_start(hb, False, False, 3)
-        self.notify_before_b = b = Gtk.CheckButton(_("Notify before"))
+        self.notify_before_b = b = Gtk.CheckButton(("Notify before"))
         adj = Gtk.Adjustment(5, 5, 20, 5, 5)
         self.notify_before_t = t = Gtk.SpinButton()
         t.set_adjustment(adj)
@@ -197,25 +320,33 @@ class ConfigDlg(Gtk.Dialog):
         t.set_value(self.applet.conf['notify_before_min'])
         hb.pack_start(b,True,True,2)
         hb.pack_start(t,False,False,2)
-        hb.pack_start(Gtk.Label(_('minutes')),False,False,2)
+        hb.pack_start(Gtk.Label(('minutes')),False,False,2)
         self._city_search_cb(self.Search_e, self.user_city)
         #self._fill_cities()
 
+    def clear_pt_changes(self, b):
+        self.Fajr_min.set_value(0)
+        self.Shrooq_min.set_value(0)
+        self.Zuhr_min.set_value(0)
+        self.Asr_min.set_value(0)
+        self.Maghrib_min.set_value(0)
+        self.Ishaa_min.set_value(0)           
+        
     def change_play_status(self, status = None):
         if status == None:
             status = self.sound_player.gst_player.get_state()
         if status == Gst.State.PLAYING:
             self.sound_file.set_sensitive(False)
-            self.play_b.set_property('label', _('Stop'))
+            self.play_b.set_property('label', ('Stop'))
         else:
             self.sound_file.set_sensitive(True)
-            self.play_b.set_property('label', _('Play'))
+            self.play_b.set_property('label', ('Play'))
 
     def play_cb(self, b):
         fn = self.sound_file.get_filename()
         if not fn:
             fn = ''
-        if b.get_label() == _('Play'):
+        if b.get_label() == ('Play'):
             if not os.path.isfile(fn):
                 return
             self.change_play_status(Gst.State.PLAYING)
@@ -287,7 +418,7 @@ class ConfigDlg(Gtk.Dialog):
         # FIXME: if same as last successful search text don't update first_match_path
         # FIXME: and if self.city_found same as first_match_path highlight in red
         # we can use self.search_last_path to fix search
-        if type(txt) == unicode:
+        if type(txt) == bytes:
             txt = txt.encode('utf-8')
         e = self.Search_e
         e.modify_fg(Gtk.StateType.NORMAL, None)
@@ -397,15 +528,21 @@ class applet(object):
         self.prayer_items = []
         kw = self.conf_to_prayer_args()
         self.prayer = itl.PrayerTimes(**kw)
+        
+        self.prayer.method.extreme=int(self.conf['pt_method'])
+        self.prayer.method.offset=self.conf['Edit_pt']
+        if self.conf['Edit_pt'] == 1:
+            self.prayer.method.offList[0]=self.conf['Fajr_minutes']
+            self.prayer.method.offList[1]=self.conf['Shrooq_minutes']
+            self.prayer.method.offList[2]=self.conf['Zuhr_minutes']
+            self.prayer.method.offList[3]=self.conf['Asr_minutes']
+            self.prayer.method.offList[4]=self.conf['Maghrib_minutes']
+            self.prayer.method.offList[5]=self.conf['Ishaa_minutes']
+
         self._init_locale(self.m.lang)
         ld = os.path.join(self.m.get_prefix(), '..', 'locale')
-        gettext.install('monajat', ld, unicode=0)
-        self.ptnames = [_("Fajr"),
-                        _("Sunrise"),
-                        _("Dhuhr"),
-                        _("Asr"),
-                        _("Maghrib"),
-                        _("Isha'a")]
+        gettext.install('monajat', ld)
+        self.ptnames = [("Fajr"),("Sunrise"),("Dhuhr"),("Asr"),("Maghrib"),("Isha'a")]
         self.clip1 = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
         self.clip2 = Gtk.Clipboard.get(Gdk.SELECTION_PRIMARY)
         self.init_menu()
@@ -414,12 +551,12 @@ class applet(object):
         self.statusicon = Gtk.StatusIcon ()
         self.statusicon.connect('popup-menu',self.popup_cb)
         self.statusicon.connect('activate',self.next_cb)
-        self.statusicon.set_title(_("Monajat"))
+        self.statusicon.set_title(("Monajat"))
         self.statusicon.set_from_file(os.path.join(self.m.get_prefix(),'monajat.svg'))
         
-        Notify.init(_("Monajat"))
+        Notify.init(("Monajat"))
         self.init_notify_cb()
-        print self.notifycaps
+        print (self.notifycaps)
         
         self.notif_last_athan = -1
         self.next_athan_delta = -1
@@ -428,17 +565,18 @@ class applet(object):
         self.last_time = 0
         self.first_notif_done = False
         self.start_time = time.time()
-        GObject.timeout_add(1, self.timer_cb)
+        #GObject.timeout_add(1, self.timer_cb)
+        self.timer_cb()
 
     def init_notify_cb(self):
         self.notifycaps = Notify.get_server_caps ()
         self.notify = Notify.Notification()
         self.notify.set_property('icon-name', os.path.join(self.m.get_prefix(),'monajat.svg'))
-        self.notify.set_property('summary', _("Monajat") )
+        self.notify.set_property('summary', ("Monajat") )
         if 'actions' in self.notifycaps:
-            self.notify.add_action("previous", _("Back"), self.notify_cb, None)
-            self.notify.add_action("next", _("Forward"), self.notify_cb, None)
-            self.notify.add_action("copy", _("copy"), self.notify_cb, None)
+            self.notify.add_action("previous", ("Back"), self.notify_cb, None)
+            self.notify.add_action("next", ("Forward"), self.notify_cb, None)
+            self.notify.add_action("copy", ("copy"), self.notify_cb, None)
         
     def show_notify_cb(self, body, *args):
         self.notify.set_property('body', body )
@@ -456,15 +594,24 @@ class applet(object):
     def default_conf(self):
         self.conf = {}
         self.conf['show_merits'] = '1'
+        self.conf['daylight_savings_time']='1'
+        self.conf['pt_method']='6'
+        self.conf['Edit_pt']='0'
+        self.conf['Fajr_minutes']='0'
+        self.conf['Shrooq_minutes']='0'
+        self.conf['Zuhr_minutes']='0'
+        self.conf['Asr_minutes']='0'
+        self.conf['Maghrib_minutes']='0'
+        self.conf['Ishaa_minutes']='0'
         self.conf['lang'] = self.m.lang
         self.conf['minutes'] = '10'
         self.conf['athan_media_file'] = os.path.join(self.m.prefix, 'athan.ogg')
-        print self.conf['athan_media_file']
+        print (self.conf['athan_media_file'])
         self.conf['notify_before_min'] = '10'
 
     def conf_to_prayer_args(self):
         kw = {}
-        if not self.conf.has_key('city_id'): return kw
+        if 'city_id' not in self.conf: return kw
         c = self.m.cities_c
         try:
             c_id = int(self.conf['city_id'])
@@ -482,7 +629,8 @@ class applet(object):
             kw["alt"] = 0.0
         kw["tz"] = kw["utc"]
         # NOTE: get DST from machine local setting
-        kw["dst"] = time.localtime().tm_isdst
+        #kw["dst"] = time.localtime().tm_isdst
+        kw["dst"] = self.conf['daylight_savings_time']
         # FIXME: dst should have the following 3 options
         # a. auto from system, b. auto from algorithm, c. specified to 0/1 by user
         #dst=kw["dst_id"]
@@ -490,17 +638,17 @@ class applet(object):
         #else:
         #    # FIXME: add DST logic here
         #    kw["dst"]=1
-        print kw
+        print (kw)
         #lat=21.43, lon=39.77, tz=3.0, dst=0, alt=0, pressure=1010, temp=10
         return kw
 
 
     def parse_conf(self, s):
         self.default_conf()
-        l1 = map(lambda k: k.split('=',1),
+        l1 = list(map(lambda k: k.split('=',1),
                  filter(lambda j: j,
-                 map(lambda i: i.strip(),s.splitlines())) )
-        l2 = map(lambda a: (a[0].strip(),a[1].strip()),filter(lambda j: len(j)==2,l1))
+                 map(lambda i: i.strip(),s.splitlines())) ))
+        l2 = list(map(lambda a: (a[0].strip(),a[1].strip()),filter(lambda j: len(j)==2,l1)))
         r = dict(l2)
         self.conf.update(dict(l2))
         return len(l1) == len(l2)
@@ -514,9 +662,9 @@ class applet(object):
             except OSError:
                 pass
         self.parse_conf(s)
-        if self.conf.has_key('city_id'):
+        if 'city_id' in self.conf:
             # make sure city_id is set using the same db
-            if not self.conf.has_key('cities_db_ver') \
+            if 'cities_db_ver' not in self.conf \
                or self.conf['cities_db_ver'] != self.m.cities_db_ver:
                    del self.conf['city_id']
             # make sure it's integer
@@ -542,6 +690,42 @@ class applet(object):
             self.conf['show_merits'] = int(self.conf['show_merits']) 
         except ValueError:
             self.conf['show_merits'] = 1
+        try:
+            self.conf['daylight_savings_time'] = int(self.conf['daylight_savings_time']) 
+        except ValueError:
+            self.conf['daylight_savings_time'] = 1            
+        try:
+            self.conf['pt_method'] = int(self.conf['pt_method']) 
+        except ValueError:
+            self.conf['pt_method'] = 6        
+        try:
+            self.conf['Edit_pt'] = int(self.conf['Edit_pt']) 
+        except ValueError:
+            self.conf['Edit_pt'] = 0            
+        try:
+            self.conf['Fajr_minutes'] = int(self.conf['Fajr_minutes']) 
+        except ValueError:
+            self.conf['Fajr_minutes'] = 0            
+        try:
+            self.conf['Shrooq_minutes'] = int(self.conf['Shrooq_minutes']) 
+        except ValueError:
+            self.conf['Shrooq_minutes'] = 0            
+        try:
+            self.conf['Zuhr_minutes'] = int(self.conf['Zuhr_minutes']) 
+        except ValueError:
+            self.conf['Zuhr_minutes'] = 0            
+        try:
+            self.conf['Asr_minutes'] = int(self.conf['Asr_minutes']) 
+        except ValueError:
+            self.conf['Asr_minutes'] = 0            
+        try:
+            self.conf['Maghrib_minutes'] = int(self.conf['Maghrib_minutes']) 
+        except ValueError:
+            self.conf['Maghrib_minutes'] = 0             
+        try:
+            self.conf['Ishaa_minutes'] = int(self.conf['Ishaa_minutes']) 
+        except ValueError:
+            self.conf['Ishaa_minutes'] = 0    
         try:
             self.conf['notify_before_min'] = int(float(self.conf['notify_before_min']))
         except ValueError:
@@ -552,15 +736,36 @@ class applet(object):
     def apply_conf(self):
         kw = self.conf_to_prayer_args()
         self.prayer = itl.PrayerTimes(**kw)
+
+        self.prayer.method.extreme=int(self.conf['pt_method'])
+        self.prayer.method.offset=self.conf['Edit_pt']
+        if self.conf['Edit_pt'] == 1:
+            self.prayer.method.offList[0]=self.conf['Fajr_minutes']
+            self.prayer.method.offList[1]=self.conf['Shrooq_minutes']
+            self.prayer.method.offList[2]=self.conf['Zuhr_minutes']
+            self.prayer.method.offList[3]=self.conf['Asr_minutes']
+            self.prayer.method.offList[4]=self.conf['Maghrib_minutes']
+            self.prayer.method.offList[5]=self.conf['Ishaa_minutes']
+
         self.update_prayer()
         self.sound_player.set_filename(self.conf['athan_media_file'])
         self.m.clear()
         self.m.set_lang(self.conf['lang'])
         self.render_body(self.m.go_forward())
+        self.last_time = time.time()
 
     def save_conf(self):
         self.conf['cities_db_ver'] = self.m.cities_db_ver
         self.conf['show_merits'] = int(self.conf_dlg.show_merits.get_active())
+        self.conf['daylight_savings_time'] = int(self.conf_dlg.daylight_savings_time.get_active())
+        self.conf['pt_method'] = int(self.conf_dlg.pt_method.get_active())
+        self.conf['Edit_pt']=int(self.conf_dlg.Edit_pt.get_active())
+        self.conf['Fajr_minutes']=int(self.conf_dlg.Fajr_min.get_value())
+        self.conf['Shrooq_minutes']=int(self.conf_dlg.Shrooq_min.get_value())
+        self.conf['Zuhr_minutes']=int(self.conf_dlg.Zuhr_min.get_value())
+        self.conf['Asr_minutes']=int(self.conf_dlg.Asr_min.get_value())
+        self.conf['Maghrib_minutes']=int(self.conf_dlg.Maghrib_min.get_value())
+        self.conf['Ishaa_minutes']=int(self.conf_dlg.Ishaa_min.get_value())
         self.conf['lang'] = self.conf_dlg.lang.get_active_text()
         self.conf['minutes'] = int(self.conf_dlg.timeout.get_value())
         self.conf['athan_media_file'] = self.conf_dlg.sound_file.get_filename()
@@ -571,7 +776,7 @@ class applet(object):
             city_id = m[p[0]][2]
             if city_id:
                 self.conf['city_id'] = city_id
-        print "** saving conf", self.conf
+        print ("** saving conf", self.conf)
         fn = os.path.expanduser('~/.monajat-applet.rc')
         s = '\n'.join(map(lambda k: "%s=%s" % (k,str(self.conf[k])), self.conf.keys()))
         try:
@@ -584,7 +789,7 @@ class applet(object):
         self.last_time = time.time()
         self.first_notif_done = True
         s = self.ptnames[self.last_athan]
-        self.show_notify_cb(_('''It's now time for %s prayer''') % s)
+        self.show_notify_cb(('''It's now time for %s prayer''') % s)
         return True
 
     def athan_notif_cb(self):
@@ -596,17 +801,17 @@ class applet(object):
         self.next_athan_delta = dt
         self.next_athan_i = i
         if dt < 30 and i != self.last_athan:
-            print "it's time for prayer number:", i
+            print ("it's time for prayer number:", i)
             self.last_athan = i
             self.sound_player.play()
             self.athan_show_notif()
             return True
         return False
-
+    @MainTimer(0.5)
     def timer_cb(self, *args):
         if not 'actions' in self.notifycaps:
             self.init_notify_cb()
-            print self.notifycaps
+            print (self.notifycaps)
         dt = int(time.time()-self.last_time)
         if self.prayer.update():
             self.update_prayer()
@@ -620,8 +825,8 @@ class applet(object):
            and self.next_athan_i != self.notif_last_athan:
                self.notif_last_athan = self.next_athan_i
                self.next_cb()
-        elif self.conf['minutes'] and dt >= self.conf['minutes']*60:
-               self.next_cb()
+        elif self.conf['minutes'] and dt >= (self.conf['minutes']*60):
+            self.next_cb()
         return True
 
     def fuzzy_delta(self):
@@ -634,19 +839,19 @@ class applet(object):
         d['minutes'] = t/60
         if d["hours"]:
             if d["minutes"] < 5:
-                r = _("""%(hours)d hours till %(prayer)s prayer""") % d
+                r = ("""%(hours)d hours till %(prayer)s prayer""") % d
             else:
-                r = _("""%(hours)d hours and %(minutes)d minutes till %(prayer)s prayer""") % d
+                r = ("""%(hours)d hours and %(minutes)d minutes till %(prayer)s prayer""") % d
         elif d["minutes"] >= 2:
-            r = _("""less than %(minutes)d minutes till %(prayer)s prayer""") % d
+            r = ("""less than %(minutes)d minutes till %(prayer)s prayer""") % d
         else:
-            r = _("""less than a minute till %(prayer)s prayer""") % d
+            r = ("""less than a minute till %(prayer)s prayer""") % d
         if "body-markup" in self.notifycaps:
-            return "<b>%s</b>\n\n" % cgi.escape(r)
+            return "<b>%s</b>\n\n" % html.escape(r)
         return "%s\n\n" % r
 
     def body_to_str(self, body):
-        if type(body) == unicode:
+        if type(body) == bytes:
             return body.encode('utf-8')
         return body
         
@@ -655,30 +860,26 @@ class applet(object):
         if not self.conf['show_merits']:
             merits = None
         if "body-markup" in self.notifycaps:
-            body = cgi.escape(m['text'])
+            body = html.escape(m['text'])
             if merits:
-                body = """{}\n\n<b>{}</b>: {}""".format(self.body_to_str(body),
-                                                        _("Its Merits"),
-                                                        self.body_to_str(cgi.escape(merits)))
+                body = """{}\n\n<b>{}</b>: {}""".format(self.body_to_str(body),("Its Merits"),self.body_to_str(html.escape(merits)))
         else:
             body = m['text']
             if merits:
-                body = """{}\n\n** {} **: {}""".format(self.body_to_str(body),
-                                                       _("Its Merits"),
-                                                       self.body_to_str(merits))
-        if type(body) == unicode:
+                body = """{}\n\n** {} **: {}""".format(self.body_to_str(body),("Its Merits"),self.body_to_str(merits))
+        if type(body) == bytes:
                 body = body.encode('utf-8')
         if "body-hyperlinks" in self.notifycaps:
             L = []
             links = m.get('links',u'').split(u'\n')
             for l in links:
                 ll = l.split(u'\t',1)
-                url = cgi.escape(ll[0])
+                url = html.escape(ll[0])
                 if len(ll) > 1:
-                    t = cgi.escape(ll[1])
+                    t = html.escape(ll[1])
                 else:
                     t = url
-                print url, t
+                print (url, t)
                 L.append(u"""<a href='{}'>{}</a>""".format(url,t))
             l = u"\n\n".join(L)
             body += self.body_to_str("\n\n" + l)
@@ -719,15 +920,17 @@ class applet(object):
         # FIXME: please add more the authors
         dlg = Gtk.AboutDialog()
         dlg.set_default_response(Gtk.ResponseType.CLOSE)
-        dlg.set_icon_from_file(os.path.join(self.m.get_prefix(),'monajat.svg'))
+        
+        dlg.set_logo_icon_name('monajat')
         try:
             dlg.set_program_name("Monajat")
         except:
             pass
-        dlg.set_name(_("Monajat"))
+        dlg.set_name(("Monajat"))
         #dlg.set_version(version)
-        dlg.set_copyright("Copyright © 2009 sabily.org")
-        dlg.set_comments(_("Monajat supplications"))
+        dlg.set_copyright("""Copyright © 2009 sabily.org
+        Copyright © 2010-2017 Sabily, Ojuba Team""")
+        dlg.set_comments(("Monajat supplications"))
         dlg.set_license("""\
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -765,7 +968,8 @@ class applet(object):
         pt = self.prayer.get_prayers()
         j = 0
         ptn = list(self.ptnames)
-        ptn[1] = ''
+        #if you want to disable sunrise time showing from the popup menu use the commands in line 952 and 980
+        #ptn[1] = ''
         for p,t in zip(ptn, pt):
             if not p: continue
             i = Gtk.MenuItem
@@ -792,7 +996,9 @@ class applet(object):
         self.menu.add(Gtk.SeparatorMenuItem.new())
 
         self.prayer_items = []
-        for j in range(5):
+        #for disabling sunerise time from the popup menu
+        #for j in range(5):
+        for j in range(6):
             i = Gtk.MenuItem("-")
             self.prayer_items.append(i)
             self.menu.add(i)
@@ -800,7 +1006,7 @@ class applet(object):
 
         self.menu.add(Gtk.SeparatorMenuItem.new())
         
-        i = Gtk.MenuItem(_("Configure"))
+        i = Gtk.MenuItem(("Configure"))
         i.connect('activate', self.config_cb)
         self.menu.add(i)
         
@@ -850,10 +1056,10 @@ class applet(object):
 
 def applet_main():
     Gtk.Window.set_default_icon_name('monajat')
-    a = applet()
-    init_dbus(a.dbus_cb)
+    #a = applet
+    setup_dbus(applet)
     Gtk.main()
+    
 
 if __name__ == "__main__":
     applet_main()
-
